Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(229)

Unified Diff: ui/aura/window_event_dispatcher.cc

Issue 1907323003: Drag and drop cleans up touch sequences from the source window. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix Mac. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/aura/window_event_dispatcher.h ('k') | ui/events/gesture_detection/gesture_provider.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/aura/window_event_dispatcher.cc
diff --git a/ui/aura/window_event_dispatcher.cc b/ui/aura/window_event_dispatcher.cc
index d34ad330b94132a61b11b0bb623da676b972620a..1d54305c171094d4dd92177a2f662a055ddb4981 100644
--- a/ui/aura/window_event_dispatcher.cc
+++ b/ui/aura/window_event_dispatcher.cc
@@ -528,12 +528,11 @@ bool WindowEventDispatcher::CanDispatchToConsumer(
return (consumer_window && consumer_window->GetRootWindow() == window());
}
-void WindowEventDispatcher::DispatchCancelTouchEvent(
- ui::GestureConsumer* raw_input_consumer,
- ui::TouchEvent* event) {
- // The touchcancel event's location is based on the last known location of
+void WindowEventDispatcher::DispatchSyntheticTouchEvent(ui::TouchEvent* event) {
+ // The synthetic event's location is based on the last known location of
// the pointer, in dips. OnEventFromSource expects events with co-ordinates
// in raw pixels, so we convert back to raw pixels here.
+ DCHECK(event->type() == ui::ET_TOUCH_CANCELLED);
event->UpdateForRootTransform(host_->GetRootTransform());
DispatchDetails details = OnEventFromSource(event);
if (details.dispatcher_destroyed)
« no previous file with comments | « ui/aura/window_event_dispatcher.h ('k') | ui/events/gesture_detection/gesture_provider.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698